#[repr(C)]
pub struct Table {
pub draw_pixel: extern "C" fn(_: *mut Context, _: u8, _: u8, _: u16) -> i32,
pub register_input: extern "C" fn(_: *mut Context, _: InputType, _: InputHandlerFn) -> i32,
}
The callbacks supplied by the OS.
Draw a colour on the display - x, y, colour
Register an input event handler for an input
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static